Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Edit ¶ added in v0.3.0
Edit opens a Drop config file in the user's editor ('drop edit envid' command). 'base' can be passed instead of an environment id to open the config file shared by all environments.
$VISUAL takes precedence over $EDITOR. If neither is set, the config path is just printed.
func InitEnv ¶
InitEnv creates a new drop environment ('drop init envid' command).
It creates the environment directory in dropHome, and environment specific config file which extends base config file in the drop config directory.
If base config file is missing (first run of 'drop init'), the function creates the default base.toml.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.